@@ -1,7 +1,7 @@
 use warnings;
 use strict;
 
-package TextFileParser 0.201;
+package TextFileParser 0.202;
 
 # ABSTRACT: an extensible Perl class to parse any text file by specifying grammar in derived classes.
 
@@ -163,7 +163,7 @@ TextFileParser - an extensible Perl class to parse any text file by specifying g
 
 =head1 VERSION
 
-version 0.201
+version 0.202
 
 =head1 SYNOPSIS
 
@@ -292,4 +292,15 @@ This software is copyright (c) 2018 by Balaji Ramasubramanian.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=TextFileParser> or by
+email to L<bug-textfileparser at rt.cpan.org|mailto:bug-textfileparser at
+rt.cpan.org>.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
